==> duiba-live-center-api-0.0.23-20210111.042901-3-sources.jar: cn/com/duiba/kjy/livecenter/api/remoteservice/liveconf/RemoteLiveInteractConfService.java <==
package cn.com.duiba.kjy.livecenter.api.remoteservice.liveconf;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.livecenter.api.dto.liveInteract.LiveInteractConfDto;
import cn.com.duiba.kjy.livecenter.api.dto.liveResource.ResourceShowConfigDto;
import cn.com.duiba.kjy.livecenter.api.param.liveInteract.LiveInteractConfQueryParam;
import javafx.util.Pair;

import java.util.List;
import java.util.Set;

/**
 * 直播互动配置服务rpc类
 * @author 吴文哲
 * @date 2020-04-02 15:27
 **/
@AdvancedFeignClient
public interface RemoteLiveInteractConfService {

    /**
     * 根据条件查询
     * @param param
     * @return
     */
    List<LiveInteractConfDto> findByCondition(LiveInteractConfQueryParam param);

    /**
     * 根据条件查询总数
     * @param param
     * @return
     */
    int countByCondition(LiveInteractConfQueryParam param);

    /**
     * 根据主键查询
     * @param id
     * @return
     */
    LiveInteractConfDto selectById(Long id);

    /**
     * 单条插入 返回主键
     * @param dto
     * @return
     */
    Long insert(LiveInteractConfDto dto);

    /**
     * 保存资料配置
     * @param liveId 直播ID
     * @param intreactIdList 互动ID集合
     * @return 执行结果
     */
    int saveResourceConf(Long liveId, List<Long> intreactIdList);

    /**
     * 保存资料配置，支持初始设置是否展示
     * @param liveId 直播ID
     * @param detailConf 每个资料的展示状态
     * @return
     */
    int saveAndShowResourceConf(Long liveId, List<ResourceShowConfigDto> detailConf);

    /**
     * 批量插入
     * @param dtoList 需要修改的列表
     * @param liveId 直播间id
     * @param interactType 互动类型
     * @return
     */
    Integer batchUpdate(List<LiveInteractConfDto> dtoList,Long liveId,Integer interactType);

    /**
     * 更新
     * @param dto 福利配置信息
     * @return 执行结果
     */
    int update(LiveInteractConfDto dto);

    /**
     * 批量减少剩余数量
     * @param id 主键
     * @param num 减少的数量
     * @return 执行结果
     */
    int batchReduceSurplusNum(Long id, int num);

    /**
     * 获取最近一个未开奖的直播前抽奖配置
     * @param liveId 直播id
     * @return 最近一个未开奖的直播前抽奖配置
     */
    LiveInteractConfDto findLastPreLottery(Long liveId);

    /**
     * 根据主键id查询
     * @param ids 主键id
     * @return 福利配置信息
     */
    List<LiveInteractConfDto> findByIds(Set<Long> ids);
}

==> duiba-live-center-api-0.0.81-20210607.090525-7-sources.jar: cn/com/duiba/kjy/livecenter/api/remoteservice/liveconf/RemoteLiveInteractConfService.java <==
package cn.com.duiba.kjy.livecenter.api.remoteservice.liveconf;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.livecenter.api.dto.liveInteract.LiveInteractConfDto;
import cn.com.duiba.kjy.livecenter.api.dto.liveResource.ResourceShowConfigDto;
import cn.com.duiba.kjy.livecenter.api.param.liveInteract.LiveInteractConfQueryParam;

import java.util.List;
import java.util.Set;

/**
 * 直播互动配置服务rpc类
 * @author 吴文哲
 * @date 2020-04-02 15:27
 **/
@AdvancedFeignClient
public interface RemoteLiveInteractConfService {

    /**
     * 根据条件查询
     * @param param
     * @return
     */
    List<LiveInteractConfDto> findByCondition(LiveInteractConfQueryParam param);

    /**
     * 根据条件查询总数
     * @param param
     * @return
     */
    int countByCondition(LiveInteractConfQueryParam param);

    /**
     * 根据主键查询
     * @param id
     * @return
     */
    LiveInteractConfDto selectById(Long id);

    /**
     * 单条插入 返回主键
     * @param dto
     * @return
     */
    Long insert(LiveInteractConfDto dto);

    /**
     * 保存资料配置
     * @param liveId 直播ID
     * @param intreactIdList 互动ID集合
     * @return 执行结果
     */
    int saveResourceConf(Long liveId, List<Long> intreactIdList);

    /**
     * 保存资料配置，支持初始设置是否展示
     * @param liveId 直播ID
     * @param detailConf 每个资料的展示状态
     * @return
     */
    int saveAndShowResourceConf(Long liveId, List<ResourceShowConfigDto> detailConf);

    /**
     * 批量插入
     * @param dtoList 需要修改的列表
     * @param liveId 直播间id
     * @param interactType 互动类型
     * @return
     */
    Integer batchUpdate(List<LiveInteractConfDto> dtoList,Long liveId,Integer interactType);

    /**
     * 更新
     * @param dto 福利配置信息
     * @return 执行结果
     */
    int update(LiveInteractConfDto dto);

    /**
     * 批量减少剩余数量
     * @param id 主键
     * @param num 减少的数量
     * @return 执行结果
     */
    int batchReduceSurplusNum(Long id, int num);

    /**
     * 获取最近一个未开奖的直播前抽奖配置
     * @param liveId 直播id
     * @return 最近一个未开奖的直播前抽奖配置
     */
    LiveInteractConfDto findLastPreLottery(Long liveId);

    /**
     * 根据主键id查询
     * @param ids 主键id
     * @return 福利配置信息
     */
    List<LiveInteractConfDto> findByIds(Set<Long> ids);

    /**
     * 批量删除操作
     */
    Integer batchDelete(List<Long> ids);

    /**
     * 根据配置interactTypes和 interactId列表查询商品
     */
    List<LiveInteractConfDto> listByInteractTypesAndInteractIds(List<Integer> types,List<Long> interactIds);

    /**
     * 根据直播间id查询置顶的一个
     * @param liveId
     * @return
     */
    LiveInteractConfDto findTopOne(Long liveId);
}
